@@ -1,4 +1,6 @@
 import datetime
+from copy import deepcopy
+from typing import Union, Optional, Type
 
 import numpy as np
 
@@ -6,15 +8,19 @@ from datacode.models.dtypes.base import DataType
 
 
 class DatetimeType(DataType):
+    names = ('datetime', 'time', 'datetime64')
 
-    def __init__(self, categorical: bool = False, ordered: bool = False):
+    def __init__(self, categorical: bool = False, ordered: bool = False,
+                 tz: Optional[Union[str, datetime.timezone]] = None):
         super().__init__(
             datetime.datetime,
             pd_class=np.datetime64,
-            names=('datetime', 'time', 'datetime64'),
             categorical=categorical,
             ordered=ordered,
         )
+        self.tz = tz
+        self.equal_attrs = deepcopy(self.equal_attrs)
+        self.equal_attrs.append('tz')
 
     @classmethod
     def from_str(cls, dtype: str, categorical: bool = False, ordered: bool = False):
@@ -25,3 +31,7 @@ class DatetimeType(DataType):
             categorical=categorical,
             ordered=ordered
         )
+
+    @property
+    def index_arg(self) -> Union[Type, str]:
+        return 'datetime64[ns]'
